WidgetStyle class abstract

Base style for all widgets.

Constructors

WidgetStyle(String backgroundColor)
WidgetStyle Constructor

Properties

backgroundColor String
Background color for the widget.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert WidgetStyle to Json Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited